@@ -1,10 +1,8 @@
 use crate::formatters::{
     trivia_formatter::{self, FormatTriviaType},
-    CodeFormatter, Range,
-};
-use full_moon::ast::{
-    punctuated::Pair, Block, Expression, LastStmt, Prefix, Return, Stmt, UnOp, Value, Var,
+    trivia_util, CodeFormatter, Range,
 };
+use full_moon::ast::{Block, Expression, LastStmt, Prefix, Return, Stmt, UnOp, Value, Var};
 #[cfg(feature = "luau")]
 use full_moon::tokenizer::TokenType;
 use full_moon::tokenizer::{Token, TokenReference};
@@ -185,47 +183,7 @@ impl CodeFormatter {
                 )))
             }
             LastStmt::Return(return_node) => {
-                let mut token = return_node.token().to_owned();
-                let mut returns = return_node.returns().to_owned();
-
-                if return_node.returns().is_empty() {
-                    token = trivia_formatter::token_reference_add_trivia(
-                        token,
-                        FormatTriviaType::Append(vec![
-                            self.create_indent_trivia(additional_indent_level)
-                        ]),
-                        FormatTriviaType::Append(vec![self.create_newline_trivia()]),
-                    );
-                } else {
-                    token = trivia_formatter::token_reference_add_trivia(
-                        token,
-                        FormatTriviaType::Append(vec![
-                            self.create_indent_trivia(additional_indent_level)
-                        ]),
-                        FormatTriviaType::NoChange,
-                    );
-
-                    // TODO: This is copied from the Assignment/LocalAssignment formatters
-                    // Retrieve last item and add new line to it
-                    if let Some(last_pair) = returns.pop() {
-                        match last_pair {
-                            Pair::End(value) => {
-                                let expression = trivia_formatter::expression_add_trailing_trivia(
-                                    value,
-                                    FormatTriviaType::Append(vec![self.create_newline_trivia()]),
-                                );
-                                returns.push(Pair::End(expression));
-                            }
-                            Pair::Punctuated(_, _) => (), // TODO: Is it possible for this to happen? Do we need to account for it?
-                        }
-                    }
-                }
-
-                LastStmt::Return(
-                    return_node
-                        .with_token(Cow::Owned(token))
-                        .with_returns(returns),
-                )
+                LastStmt::Return(self.return_add_trivia(return_node, additional_indent_level))
             }
             #[cfg(feature = "luau")]
             LastStmt::Continue(continue_node) => {
@@ -241,19 +199,63 @@ impl CodeFormatter {
     }
 
     pub fn format_block<'ast>(&mut self, block: Block<'ast>) -> Block<'ast> {
-        let formatted_statements: Vec<(Stmt<'ast>, Option<Cow<'ast, TokenReference<'ast>>>)> =
-            block
-                .iter_stmts()
-                .map(|stmt| {
-                    let range_in_stmt = CodeFormatter::get_range_in_stmt(stmt);
-                    let additional_indent_level = self.get_range_indent_increase(range_in_stmt);
-                    let stmt = self.format_stmt(stmt);
-                    (
-                        self.stmt_add_trivia(stmt, additional_indent_level),
-                        None, // The second parameter in the tuple is for semicolons - we do not want any semi-colons
-                    )
-                })
-                .collect();
+        let mut formatted_statements: Vec<(Stmt<'ast>, Option<Cow<'ast, TokenReference<'ast>>>)> =
+            Vec::new();
+
+        let mut stmt_iterator = block.iter_stmts().peekable();
+        while let Some(stmt) = stmt_iterator.next() {
+            let range_in_stmt = CodeFormatter::get_range_in_stmt(stmt);
+            let additional_indent_level = self.get_range_indent_increase(range_in_stmt);
+            let stmt = self.format_stmt(stmt);
+
+            // Need to check next statement if it is a function call, with a parameters expression as the prefix
+            // If so, removing a semicolon may lead to ambiguous syntax
+            // Ambiguous syntax can only occur if the current statement is a (Local)Assignment, FunctionCall or a Repeat block
+            let require_semicolon = match stmt {
+                Stmt::Assignment(_)
+                | Stmt::LocalAssignment(_)
+                | Stmt::FunctionCall(_)
+                | Stmt::Repeat(_) => {
+                    let next_stmt = stmt_iterator.peek();
+                    match next_stmt {
+                        Some(next_stmt) => match next_stmt {
+                            Stmt::FunctionCall(function_call) => match function_call.prefix() {
+                                Prefix::Expression(expr) => match expr {
+                                    Expression::Parentheses { .. } => true,
+                                    _ => false,
+                                },
+                                _ => false,
+                            },
+                            _ => false,
+                        },
+                        None => false,
+                    }
+                }
+                _ => false,
+            };
+
+            let mut trivia_stmt = self.stmt_add_trivia(stmt, additional_indent_level);
+
+            // If we have a semicolon, we need to push all the trailing trivia from the statement
+            // and move it to the end of the semicolon
+            let semicolon = match require_semicolon {
+                true => {
+                    let (updated_stmt, trivia) = trivia_util::get_stmt_trailing_trivia(trivia_stmt);
+                    trivia_stmt = updated_stmt;
+                    Some(Cow::Owned(trivia_formatter::token_reference_add_trivia(
+                        TokenReference::symbol(";").expect("could not make semicolon"),
+                        FormatTriviaType::NoChange,
+                        FormatTriviaType::Append(trivia),
+                    )))
+                }
+                false => None,
+            };
+
+            formatted_statements.push((trivia_stmt, semicolon))
+        }
+
+        // Drop the stmt_iterator as we do not need it anymore and we still need to use `block`
+        drop(stmt_iterator);
 
         let formatted_last_stmt = match block.last_stmt() {
             Some(last_stmt) => {
